
'
' Little Bes: the lost rabbits
'
' Version 0.6 by Stelios Mersinas (steliosm@gmail.com)
'
'
'    This program is free software: you can redistribute it and/or modify
'    it under the terms of the GNU General Public License as published by
'    the Free Software Foundation, either version 3 of the License, or
'    (at your option) any later version.
'
'    This program is distributed in the hope that it will be useful,
'    but WITHOUT ANY WARRANTY; without even the implied warranty of
'    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
'    GNU General Public License for more details.
'
'    You should have received a copy of the GNU General Public License
'    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'
'
'
' Changelog:
'
' v0.6
'  Removed water tiles: Added as static background. This saves on tile's count.
'  Added 'Play again' question prompt.
'
' v0.5
'  Smoother animation:
'   Each frame gets a fixed time to complete all it's calculations and sprite move.
'  Added a Splash screen!
'
' v0.4
'  New character sprite
'
' v0.3
'  Added F2 key to restart the same level. Should help to test/debug new levels.
'  Added Confirm dialog before quitting.
'
'


[start]
    ' Do not bring up the main window
    nomainwin

    ' Create the game window
    gosub [CreateWindow]

    ' Display the Splash Screen
    gosub [StartScreen]

    ' Load the sprites
    gosub [LoadSprites]

    ' Init game engine variables

    ' Define the game speed
    GameTick = 80
    ' Define the tile sizes
    TileWidth = 36
    TileHeight = 36
    ' Define the walking distance in pixels for the player
    PlayerSpeed = 9
    ' Set the speed of gravity for the player
    PlayerGravity = 9
    ' Define the starting level
    CurrentLevel = 1
    ' Set the number of lives
    Lives = 3
    ' Define the number of levels
    MaxLevel = 10
    ' Set a flag to check if the bitmaps are loaded
    BitmapsLoaded = 0


[StartLevel]
    ' Disable the timer
    timer 0

    ' Check if the player is dead
    if Lives < 0 then
        ' Display the Game Over screen
        goto [GameOver]
    end if

    ' Load the map
    gosub [LoadMap]

    ' Set the focus to the graphics window
    #main "setfocus"

    ' Init the game variables
    PlayerWalking = 0
    PlayerCanJump = 0
    PlayerJumpCount = 0

    ' Enable the game timer.
    timer GameTick, [MainLoop]

    ' Wait here for the timer to trigger off
    wait


[MainLoop]
    ' Get the player's sprite current cordinates
    #main "spritexy? player PlayerX PlayerY"

    ' Check the keyboard for user input
    gosub [CheckInput]

    ' Apply the gravity force
    gosub [ApplyGravity]

    ' Apply the movement
    gosub [ApplyMovement]

    ' Resolve any collisions
    gosub [ResolveCollisions]

    ' Update the status line
    gosub [UpdateStatus]

    ' Display the sprites
    #main "drawsprites"

    ' Wait for user input (quit) or the timer event
    wait


[SwitchLevel]
    ' Switch the carrunt level to the next
    ' Stop the timer
    timer 0
    ' Increase the map number and start the next level
    CurrentLevel = CurrentLevel + 1
    ' Have we reached the last level?
    if CurrentLevel > MaxLevel then goto [GameOver]

    ' Set a flag to re-init the picklist before placing the tiles
    initPickList = 1
    ' Play the teleport sound
    playwave "sounds\teleport.wav",async
    ' Start the new level
    goto [StartLevel]


'
' Subroutines section
'

[ApplyGravity]
    ' Check if the player is mid-air from a previous jump and increase the counter
    if PlayerGravity < 0 then PlayerJumpCount = PlayerJumpCount + 1

    ' Check the Jump counter: If counter > 6 then revert the player's gravity
    if PlayerJumpCount > 6 then
        PlayerGravity = PlayerGravity * -1
        PlayerJumpCount = 0
    end if

    ' Move the player to the new location
    #main "spritexy player "; PlayerX; " "; PlayerY + PlayerGravity

    ' Check if the player fell off the screen
    if (PlayerY + PlayerGravity) > WindowHeight - 20 then
        ' Loose a life
        Lives = Lives - 1
        ' Play a sound
        playwave "sounds\ouch.wav",sync
        goto [StartLevel]
    end if

    ' Get the collision list
    #main "spritecollides player list$"

    ' Resolve the collisions with blocks.
    ' We only collide with tiles having the 'block' part in their name
    findBlock = instr(list$,"block")
    if findBlock > 0 then
        ' Check if player is walking and set the proper sprite
        if PlayerWalking = 0 then #main "spriteimage player player-1"

        ' We have a block, leave the player to his previous Y location.
        PlayerNewY = PlayerY

        ' Check if the player was jumping
        if PlayerJumpCount > 0 then
            PlayerJumpCount = 6
        end if

        ' Move the player back to the previous location
        #main "spritexy player "; PlayerX; " "; PlayerNewY

        ' Enable the player to jump again
        PlayerCanJump = 1
    else
        ' Set the new Y value - no need to redraw the sprite, it's already there.
        PlayerNewY = PlayerY + PlayerGravity

        ' The player is already in the air. He cannot jump again.
        PlayerCanJump = 0
    end if

' Go back
return


[ApplyMovement]
    ' Apply the horizontal movement
    if PlayerWalking <> 0 then
        ' Cycle through the player's sprite images if he's not jumping
        if PlayerJumpCount = 0 then
            ' Cycle through the player's images
            #main "cyclesprite player 1"
        end if

        ' Apply movement to the player and check for collisions
        TempPlayerX = PlayerX + PlayerSpeed * PlayerWalking

        ' Move the player to the new location
        #main "spritexy player "; TempPlayerX; " "; PlayerNewY

        ' Get the collision list
        #main "spritecollides player list$"

        ' Resolve the collisions with blocks.
        ' We only collide with tiles having the 'block' part in their name
        findBlock = instr(list$,"block")
        if findBlock > 0 then
            ' Move the player to the previous location
            PlayerNewX = PlayerX

            ' Stop the player from walking
            PlayerWalking = 0

            ' Move the player to the previous location
            #main "spritexy player "; PlayerNewX; " "; PlayerNewY
        else
            ' Keep the current X position
            PlayerNewX = TempPlayerX
        end if

        ' Move the sprites
        gosub [MoveSprites]

        ' Reset the player unless he is jumping
        if PlayerJumpCount = 0 then
            ' Stop the player from making another step
            PlayerWalking = 0
        end if

    end if

' Go back
return


[ResolveCollisions]
    ' Resolve collisions with the level exit
    findExit = instr(list$,"exitlevel")
    if findExit>0 then
        ' Change the game level
        goto [SwitchLevel]
    end if

    ' Resolve collisions with rabbits
    findRabbit = instr(list$,"rabbit")
    if findRabbit>0 then
        trimmedList$ = mid$(list$,findRabbit)
        findRabbit$ = word$(trimmedList$,1)
        if findRabbit$<>"" then
            #main "removesprite "; findRabbit$
            ' Add sprite to the pinkup list
            pickList$ = findRabbit$; " "; pickList$
            ' Play the pick up sound
            playwave "sounds\pick.wav", async
            ' Add one up!
            Score = Score + 1
        end if
    end if

' Go back
return


[MoveSprites]
    ' Get the screen center
    '#main "home;posxy xHome yHome"

    ' Calculate the distance between the player position and a fixed location on the screen.
    ' If the player is below the location then move the player sprite else move the tiles.
    if PlayerNewX < 200  And PlayerWalking = 1 then
        ' Move the player
        moveTo = 0
    else
        ' Move the tiles
        moveTo = -1 * PlayerSpeed * PlayerWalking
    end if

    ' Check if the player is walking
    if moveTo <> 0 then

        ' Move the player
        #main "spritexy player "; PlayerX; " "; PlayerNewY

        ' Move the blocks
        for counter = 1 to LevelBlocks
            ' Move the blocks
            #main "spritexy? block"; counter; " getX getY"
            #main "spritexy block"; counter; " "; getX + moveTo; " "; getY
        next

        ' Move the water blocks
        for counter = 1 to WaterBlocks
            ' Move the blocks
            #main "spritexy? water"; counter; " getX getY"
            #main "spritexy water"; counter; " "; getX + moveTo; " "; getY
        next

        ' Move the ice blocks
        for counter = 1 to IceBlocks
            ' Move the blocks
            #main "spritexy? iceblock"; counter; " getX getY"
            #main "spritexy iceblock"; counter; " "; getX + moveTo; " "; getY
        next

        ' Move the clouds in a Parallax way (smaller steps)
         for counter = 1 to CloudBlocks
           ' Move the clouds
            #main "spritexy? cloud"; counter; " getX getY"
            #main "spritexy cloud"; counter; " "; getX + (moveTo/3) - 1; " "; getY
        next

        ' Move the rabbits
        for counter = 1 to LevelRabbits
           ' Move the rabbits not in the Picked list
            if instr( pickList$, "rabbit"; counter; " " ) = 0 then
                #main "spritexy? rabbit"; counter; " getX getY"
                #main "spritexy rabbit"; counter; " "; getX + moveTo; " "; getY
            end if
        next

        ' Move the level exit portal
        #main "spritexy? exitlevel getX getY"
        #main "spritexy exitlevel "; getX + moveTo; " "; getY

    end if

' Go back
return


[LoadMap]
    '
    ' Remove the previous tiles
    '

    ' Remove the items
    if LevelRabbits > 0 then
        for counter = 1 To LevelRabbits
            if instr(pickList$,"rabbit"; counter; " ") = 0 then
                #main "removesprite rabbit"; counter
            end if
        next counter
    end if

    ' Remove the blocks
    if LevelBlocks > 0 then
        for counter = 1 To LevelBlocks
            #main "removeSprite block"; counter
        next counter
    ' Remove the player and the exit sign
    #main "removeSprite exitlevel"
    #main "removeSprite player"
    end if

    ' Remove the water blocks
    if WaterBlocks > 0 then
        for counter = 1 to WaterBlocks
            #main "removesprite water"; counter
        next counter
    end if

    ' Remove the ice blocks
    if IceBlocks > 0 then
        for counter = 1 to IceBlocks
            #main "removesprite iceblock"; counter
        next counter
    end if

    ' Remove the clouds
    if CloudBlocks > 0 then
        for counter = 1 to CloudBlocks
            #main "removesprite cloud"; counter
        next counter
    end if

    '
    ' Load the new tiles
    '

    ' Init the variables
    LevelBlocks = 0
    LevelRabbits = 0
    WaterBlocks = 0
    IceBlocks = 0
    CloudBlocks = 0
    LevelPlayerExists = 0

    ' Load the level map
    Open "levels\level-"; CurrentLevel; ".txt" for input as #map
    while not(eof(#map))
        line input #map, mapdata$
        if left$(mapdata$,1)<>"#" then
            if instr(mapdata$,",")>0 then
                mapwidth = val( word$(mapdata$,1,",") )
                mapheight = val( word$(mapdata$,2,",") )
            else
                total$ = trim$(total$;mapdata$)
            end if
        end if
    wend
    Close #map

    ' Check if the is a flag to re-init the pickList
    if initPickList = 1 then
        ' Init the pickList
        pickList$ = ""
        initPickList = 0
    end if

    ' Lay down the map tiles
    for y = 1 to mapheight
        for x = 1 to mapwidth
            mapval = mapval + 1
            mapdata$ = mid$(total$,mapval,1)
            if mapdata$ <> "0" then
                select case mapdata$
                case "A"
                    ' Add ground blocks
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-a"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "B"
                    ' Add more ground blocks
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-b"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "C"
                    ' Add even more ground blocks
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-c"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "D"
                     ' Add some more ground blocks
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-d"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "E"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-e"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "F"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-f"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "G"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-g"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "H"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-h"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "I"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-i"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "J"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-j"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "K"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-k"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "L"
                    ' Ground blocks!
                    LevelBlocks = LevelBlocks + 1
                    #main "addsprite block"; LevelBlocks; " block-l"
                    #main "spritexy block"; LevelBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "P"
                    ' Place the ice blocks
                    IceBlocks = IceBlocks + 1
                    #main "addsprite iceblock"; IceBlocks; " block-p"
                    #main "spritexy iceblock"; IceBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "Q"
                    ' Place the ice blocks
                    IceBlocks = IceBlocks + 1
                    #main "addsprite iceblock"; IceBlocks; " block-q"
                    #main "spritexy iceblock"; IceBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "Z"
                    ' Nice clouds
                    CloudBlocks = CloudBlocks + 1
                    #main "addsprite cloud"; CloudBlocks; " cloud"
                    #main "spritexy cloud"; CloudBlocks; " "; (x * TileWidth) - TileWidth; " "; y * TileHeight
                case "Y"
                    ' Place the player sprite
                    LevelPlayerExists = 1
                    px = (x * TileWidth) - TileWidth
                    py = y * TileHeight
                case "X"
                    ' Place the rabbits sprites
                    LevelRabbits = LevelRabbits + 1
                    if instr(pickList$,"rabbit"; LevelRabbits; " ") = 0 then
                        #main "addsprite rabbit"; LevelRabbits; " rabbit"
                        #main "spritexy rabbit"; LevelRabbits; " "; (x * TileWidth) - TileWidth + 4; " "; (y * TileHeight) + 9
                    end if
                case "W"
                    ' Place the exit sign
                    #main "addsprite exitlevel exit"
                    #main "spritexy exitlevel "; (x * TileWidth) - TileWidth + 9; " "; (y * TileHeight) + 9
                    #main "spriteround exitlevel"
                end select
            end if
        next
    next

    ' Add the player sprite
    if LevelPlayerExists = 0 then
        ' This should never happend!
        notice "There is not a player in map!"
        goto [QuitGame]
    else
        ' Add the player sprite
        #main "addsprite player player-1 player-2 player-3"
        #main "spritexy player ";px;" ";py - 6 ' Player pixel is 18x23
        #main "spriteorient player mirror"
        #main "spriteround player"
    end if

    ' Re-init the variables
    total$ = ""
    mapwidth = 0
    mapheight = 0
    mapdata$ = ""
    mapval = 0
    mapdata = 0

    ' Update the status line
    gosub [UpdateStatus]

' end of map loading subroutine
return


[LoadSprites]
    ' Player character
    loadbmp "player-1","images\bes1.bmp"
    loadbmp "player-2","images\bes2.bmp"
    loadbmp "player-3","images\bes3.bmp"
    ' Ground blocks
    loadbmp "block-a", "images\block-a.bmp"
    loadbmp "block-b", "images\block-b.bmp"
    loadbmp "block-c", "images\block-c.bmp"
    loadbmp "block-d", "images\block-d.bmp"
    loadbmp "block-e", "images\block-e.bmp"
    loadbmp "block-f", "images\block-f.bmp"
    loadbmp "block-g", "images\block-g.bmp"
    loadbmp "block-h", "images\block-h.bmp"
    loadbmp "block-i", "images\block-i.bmp"
    loadbmp "block-j", "images\block-j.bmp"
    loadbmp "block-k", "images\block-k.bmp"
    loadbmp "block-l", "images\block-l.bmp"
    ' Water blocks
    loadbmp "block-m", "images\block-m.bmp"
    ' Ice block
    loadbmp "block-p", "images\block-p.bmp"
    loadbmp "block-q", "images\block-q.bmp"
    ' Exit
    loadbmp "exit", "images\portal.bmp"
    ' Cloud
    loadbmp "cloud", "images\cloud.bmp"
    ' Rabbit
    loadbmp "rabbit", "images\rabbit.bmp"

    ' Create the background
    #main "home; down;fill 195 219 231"

    ' Lay the water blocks
    for water = 0 to 13
        #main "addsprite water"; water; " block-m"
        #main "spritexy water"; water; " "; water * 36; " 288"
    next water

    ' Grab the screen
    #main "getbmp bg 0 0 "; WindowWidth; " "; WindowHeight
    #main "background bg"

    ' Set the bitmaps loaded flag
    BitmapsLoaded = 1

' Go back
return


[UpdateStatus]
    ' Update the status line
    UI$ = space$(20); "Level: "; CurrentLevel; space$(20); "Score: "; Score; space$(20); "Lives: "; Lives
    #main.gbx "place 10 12"
    #main.gbx "|"; UI$

'Go back
return


[UnloadSprites]
    ' Check the bitmaps loaded flag
    if BitmapsLoaded = 1 then
        ' Unload the blocks
        unloadbmp "block-a"
        unloadbmp "block-b"
        unloadbmp "block-c"
        unloadbmp "block-d"
        unloadbmp "block-e"
        unloadbmp "block-f"
        unloadbmp "block-g"
        unloadbmp "block-h"
        unloadbmp "block-i"
        unloadbmp "block-j"
        unloadbmp "block-k"
        unloadbmp "block-l"
        unloadbmp "block-m"
        unloadbmp "block-n"
        unloadbmp "block-o"
        unloadbmp "block-p"
        unloadbmp "block-q"

        ' Unload the clouds
        unloadbmp "cloud"

        ' Unload the player character
        unloadbmp "player-1"
        unloadbmp "player-2"
        unloadbmp "player-3"

        ' Unload the rabbits
        unloadbmp "rabbit"

        ' Unload the exit sign
        unloadbmp "exit"
    end if

' Go back
return


[CheckInput]
    ' The value 32769 means that the key is down at the time of check.
    ' The value 32768 means that the key was pressed before we check.
    ' Check if the player wants to go backwards
    if getKey(_VK_LEFT) and 32769 then
        ' Move the player backwards
        PlayerWalking = -1
        #main "spriteorient player normal"
    end if

    ' Check if the player wants to go forward
    if getKey(_VK_RIGHT) and 32769 then
        ' Move the player forward
        PlayerWalking = 1
        #main "spriteorient player mirror"
    end if

    ' Check if the player wants to jump
    if getKey(_VK_UP) and 32769 then
        ' Make the player jump
        if PlayerCanJump then
            ' Reverse the gravity value: This will make the player to move up instead of down
            PlayerGravity = PlayerGravity * -1
            ' Play the jump sound
            playwave "sounds\jump.wav", async
            ' Change the sprite
        end if
        #main "spriteimage player player-1"
    end if

    ' Check if the player wants to quit
    if getKey(_VK_ESCAPE) and 32769 then
        ' Player wants to quit
        goto [QuitGame]
    end if

    ' Check if the player wants to go to the next level
    if getKey(_VK_F1) and 32769 then
        ' Player wants to switch to the next level
        goto [SwitchLevel]
    end if

    ' Check if the player wants to restart the level
    if getKey(_VK_F2) and 32769 then
        ' Player wants to switch to the next level
        goto [StartLevel]
    end if

'Go back
return


[CreateWindow]
    ' Prepare the game window
    WindowWidth = 500
    WindowHeight = 356
    UpperLeftX = int((DisplayWidth-WindowWidth)/2)
    UpperLeftY = int((DisplayHeight-WindowHeight)/2)

    ' Create the status line
    graphicbox #main.gbx, 0, 0, WindowWidth, 15

    ' Create the graphics window
    open "Little Bes - The lost rabbits" for graphics_nf_nsb as #main
    #main "trapclose [QuitGame]"

    ' Setup the status line
    #main.gbx "disable"
    #main.gbx "font arial bold 7 16"
    #main.gbx "down; fill black; color white; backcolor black"

' Go back
return


[StartScreen]
    ' Create the background
    #main "down; fill black"
    #main "getbmp bg 0 0 "; WindowWidth; " "; WindowHeight
    #main "background bg"

    ' Load the title specific sprites
    loadbmp "title-1", "images\title_1.bmp"
    loadbmp "title-2", "images\title_2.bmp"

    ' Place everything nicely on the screen
    #main "addsprite title-1 title-1"
    #main "addsprite title-2 title-2"
    #main "spritexy title-1 65 70"
    #main "spritexy title-2 110 140"
    #main "drawsprites"
    #main "getbmp screen 0 0 "; WindowWidth; " "; WindowHeight
    #main "drawbmp screen 0 0"
    #main "flush"

    ' Make a 3sec delay
    timer 3000, [StartScreenEnd]

    ' Wait here for an event
    wait

[StartScreenEnd]
    ' Remove the sprites
    #main "removesprite title-1"
    #main "removesprite title-2"

    ' Unload the bitmaps
    unloadbmp "title-1"
    unloadbmp "title-2"

' Go back
return


[GameOver]
    ' Disable the timer
    timer 0

    ' Load the title specific sprites
    loadbmp "game-over", "images\game-over.bmp"

    ' Place everything nicely on the screen
    #main "addsprite game-over game-over"
    #main "spritexy game-over 65 70"
    #main "drawsprites"
    #main "getbmp screen 0 0 "; WindowWidth; " "; WindowHeight
    #main "drawbmp screen 0 0"
    #main "place 110 170"
    #main "font arial bold 7 24"
    #main "color black; backcolor 195 219 231"
    #main "|"; "You have managed to collect "; Score; " rabbits!"
    #main "flush"

    '  Sleep for 5 seconds
    timer 5000, [PlayAgain]

    ' Wait here
    wait


[PlayAgain]
    ' Disable the timer
    timer 0

    ' Ask the user if he wants to play again
    confirm "Would you like to play again?"; answer$
    if answer$ = "no" then

       ' Unload the bitmaps
        gosub [UnloadSprites]

        ' Close the main window
        close #main

        ' End the application
        end
    end if


[RestartGame]
    ' Remove the sprites
    #main "removesprite game-over"

    ' Unload bitmap
    unloadbmp "game-over"

    ' Re-init the lives
    Lives = 3
    ' Set the level to be the starting level
    CurrentLevel = 1
    ' Restart the score
    Score = 0
    ' Go to start game
    goto [StartLevel]


[QuitGame]
    ' Disable the timer
    timer 0

    ' Ask the user if he really wants to quit
    confirm "Are you sure you want to quit?"; answer$
    if answer$ = "yes" then

       ' Unload the bitmaps
        gosub [UnloadSprites]

        ' Close the main window
        close #main

        ' End the application
        end
    end if

    ' Enable the timer
    timer GameTick, [MainLoop]

' Go back
return


'
' Functions section
'

function getKey(key)
    ' Function to return the key value currently pressed
    CallDLL #user32, "GetAsyncKeyState", _
    key as Long, _
    getKey as Long
end function


' The end!
end

