
'
' Translate TMX CSV format to LittleBes game level format.
' Version 0.3 by Stelios Mersinas
'

nomainwin

[OpenFile]
' Select a file
filedialog "Open Tiled (.tmx) file", "*.tmx", fileName$

' Check if the user has entered a filename
if fileName$ = "" then end

' Open the selected file
open fileName$ for input as #file

' Init the variables
dim level$(8)
counter = 1
myChar$ = ""

' Set up the translation map
map$ = "ABCDEFGHI0JKL00MNOPQWXYZ0"

' Loop over the file line by line
while eof(#file) = 0
    ' Read until LF char (UNIX EOL)
    text$ = inputto$(#file, chr$(10))

    ' The second line contains the map width.
    if counter = 2 then
        ' Locate the word 'width' in the line
        wordPos = instr( text$, "width")

        ' Grab the width size
        mapsize$ = mid$(text$, wordPos + 7, 3)

        ' Check if the last character is a double-quote
        ' This could happen if the map size is lower than 100 tiles wide
        if right$(mapsize$, 1) = chr$(34) then
            ' Remove the double-quote character
            mapsize$ = left$(mapsize$, 2)
        end if
    end if

    ' Check if we passed the 7th line
    if counter > 7 and counter < 16 then
        ' Start manipulating the data

        ' Loop over every single character of the line
        for pos = 1 to len(text$)
            char$ = mid$ (text$, pos, 1)

            if char$ <> "," then
                ' Still on the same field: Concatenate the string
                myChar$ = myChar$ + char$
            end if

            if char$ = "," or pos = len(text$) then
                ' Lookup the value
                if myChar$ <> "0" then
                    newChar$ = mid$(map$, val(myChar$), 1)
                else
                    newChar$ = "0"
                end if

                ' Clear the string
                myChar$ = ""

                ' Add the value to the new variable
                level$(counter - 7) = level$(counter-7) + newChar$
            end if
        next pos
    end if

    ' Increase the counter
    counter = counter +1
wend

' Close the map file
close #file


[GetFileName]
' Get the filename to store the data
filedialog "Save Game Map As...", "*.txt", fileName$

' Check if the user has entered a filename
if fileName$ = "" then end

' Check if the file exists
if fileExists (fileName$) then
    ' Ask the user if he wants to overwrite the file
    confirm "File already exists, overwrite?"; answer$

    ' Check the answer
    if answer$ = "no" then
        goto [GetFileName]
    end if
end if


[SaveFile]
' Save the data
open  fileName$ for output as #file

' Save the map size
print #file, mapsize$; ",8"

' Loop over the array
for newcounter  =  1 to 8
    print #file, level$(newcounter)
next newcounter

' Close the file
close #file

' Notify the user that the conversion is over
notice "Map Conversion" + chr$(13) + "Map conversion is completed!"

'
' Functions
'
function fileExists(file$)
    ' Returns 0 if file does not exists
    dim info$(10, 10)
    files path$, file$, info$()
    fileExists = val(info$(0, 0))
end function


' Program end
end

